| Title: | Dhersz Utility Functions |
|---|---|
| Description: | Utility functions frequently used by dhersz. |
| Authors: | Daniel Herszenhut [aut, cre] (ORCID: <https://orcid.org/0000-0001-8066-1105>) |
| Maintainer: | Daniel Herszenhut <[email protected]> |
| License: | GPL-3 |
| Version: | 0.0.0.9016 |
| Built: | 2026-05-27 10:35:35 UTC |
| Source: | https://github.com/dhersz/dhmisc |
Downloads Brazil's rapid transit corridors and stops made available by ITDP Brasil at Mobilidados.
brazil_rapid_transit()brazil_rapid_transit()
A list with two entries: one sf with the transit stops, and another one with the transit corridors.
Automatically bumps package version and optionally updates package metadata.
Helper around desc::desc_bump_version() and codemetar::write_codemeta().
bump_pkg_version(which = "dev", update_metadata = TRUE)bump_pkg_version(which = "dev", update_metadata = TRUE)
which |
Component of version number to bump, either |
update_metadata |
Should |
## Not run: bump_pkg_version()## Not run: bump_pkg_version()